"""Pin definitions for Jetson TX2 NX."""

from adafruit_blinka.microcontroller.tegra.t186 import pin

SDA = pin.SDA
SCL = pin.SCL
SDA_1 = pin.SDA_1
SCL_1 = pin.SCL_1

D4 = pin.J04
D5 = pin.N01
D6 = pin.EE02
D7 = pin.Y03
D8 = pin.H03
D9 = pin.H01
D10 = pin.H02
D11 = pin.H00
D12 = pin.U00
D13 = pin.U05
D16 = pin.W05
D17 = pin.W04
D18 = pin.J00
D19 = pin.J03
D20 = pin.J02
D21 = pin.J01
D22 = pin.C02
D23 = pin.C03
D24 = pin.V04
D25 = pin.V02
D26 = pin.V03
D27 = pin.V01

CE1 = D7
CE0 = D8
MISO = D9
MOSI = D10
SCLK = D11
SCK = D11
